@@ -29,7 +29,7 @@ from metalsmith import sources
 
 NODE_FIELDS = ['name', 'id', 'instance_info', 'instance_id', 'is_maintenance',
                'maintenance_reason', 'properties', 'provision_state', 'extra',
-               'last_error', 'traits']
+               'last_error', 'traits', 'resource_class', 'conductor_group']
 
 
 class TestInit(testtools.TestCase):
@@ -98,6 +98,8 @@ class TestReserveNode(Base):
         kwargs.setdefault('id', '000')
         kwargs.setdefault('properties', {'local_gb': 100})
         kwargs.setdefault('instance_info', {})
+        kwargs.setdefault('instance_id', None)
+        kwargs.setdefault('is_maintenance', False)
         return mock.Mock(spec=NODE_FIELDS, **kwargs)
 
     def test_no_nodes(self):
@@ -108,7 +110,7 @@ class TestReserveNode(Base):
         self.assertFalse(self.api.baremetal.update_node.called)
 
     def test_simple_ok(self):
-        nodes = [self._node()]
+        nodes = [self._node(resource_class='control')]
         self.api.baremetal.nodes.return_value = nodes
 
         node = self.pr.reserve_node('control')
@@ -129,7 +131,8 @@ class TestReserveNode(Base):
 
     def test_with_capabilities(self):
         nodes = [
-            self._node(properties={'local_gb': 100, 'capabilities': caps})
+            self._node(properties={'local_gb': 100, 'capabilities': caps},
+                       resource_class='control')
             for caps in ['answer:1', 'answer:42', None]
         ]
         expected = nodes[1]
@@ -235,8 +238,14 @@ class TestReserveNode(Base):
             instance_info={'capabilities': {'cat': 'meow'}})
 
     def test_provided_nodes_no_match(self):
-        nodes = [self._node(resource_class='compute', conductor_group='loc1'),
-                 self._node(resource_class='control', conductor_group='loc2')]
+        nodes = [
+            self._node(resource_class='compute', conductor_group='loc1'),
+            self._node(resource_class='control', conductor_group='loc2'),
+            self._node(resource_class='control', conductor_group='loc1',
+                       is_maintenance=True),
+            self._node(resource_class='control', conductor_group='loc1',
+                       instance_id='abcd')
+        ]
 
         self.assertRaises(exceptions.NodesNotFound,
                           self.pr.reserve_node, candidates=nodes,
@@ -268,6 +277,10 @@ class TestProvisionNode(Base):
                 self.api.network.create_port.return_value.id
             ],
         }
+        self.configdrive_mock = self.useFixture(
+            fixtures.MockPatchObject(_config.InstanceConfig,
+                                     'build_configdrive', autospec=True)
+        ).mock
 
     def test_ok(self):
         inst = self.pr.provision_node(self.node, 'image',
@@ -283,6 +296,8 @@ class TestProvisionNode(Base):
         self.api.baremetal.update_node.assert_called_once_with(
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
+        self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
+                                                      self.node.name)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(self.api.network.delete_port.called)
@@ -371,6 +386,8 @@ class TestProvisionNode(Base):
         self.api.baremetal.update_node.assert_called_once_with(
             self.node, instance_info=self.instance_info, extra=self.extra)
         self.api.baremetal.validate_node.assert_called_once_with(self.node)
+        self.configdrive_mock.assert_called_once_with(mock.ANY, self.node,
+                                                      hostname)
         self.api.baremetal.set_node_provision_state.assert_called_once_with(
             self.node, 'active', config_drive=mock.ANY)
         self.assertFalse(
@@ -1305,6 +1322,10 @@ class TestUnprovisionNode(Base):
 
 
 class TestShowInstance(Base):
+    def setUp(self):
+        super(TestShowInstance, self).setUp()
+        self.node.provision_state = 'active'
+
     def test_show_instance(self):
         self.mock_get_node.side_effect = lambda n, *a, **kw: self.node
         inst = self.pr.show_instance('id1')
@@ -1315,7 +1336,7 @@ class TestShowInstance(Base):
         self.assertIs(inst.uuid, self.node.id)
 
     def test_show_instances(self):
-        self.mock_get_node.side_effect = [self.node, mock.Mock()]
+        self.mock_get_node.side_effect = [self.node, self.node]
         result = self.pr.show_instances(['1', '2'])
         self.mock_get_node.assert_has_calls([
             mock.call(self.pr, '1', accept_hostname=True),
@@ -1343,16 +1364,16 @@ class TestListInstances(Base):
         super(TestListInstances, self).setUp()
         self.nodes = [
             mock.Mock(spec=NODE_FIELDS, provision_state=state,
-                      instance_info={'metalsmith_hostname': '1234'})
+                      instance_id='1234')
             for state in ('active', 'active', 'deploying', 'wait call-back',
-                          'deploy failed', 'available')
+                          'deploy failed', 'available', 'available', 'enroll')
         ]
-        del self.nodes[-1].instance_info['metalsmith_hostname']
+        self.nodes[6].instance_id = None
         self.api.baremetal.nodes.return_value = self.nodes
 
     def test_list(self):
         instances = self.pr.list_instances()
         self.assertTrue(isinstance(i, _instance.Instance) for i in instances)
-        self.assertEqual(self.nodes[:5], [i.node for i in instances])
+        self.assertEqual(self.nodes[:6], [i.node for i in instances])
         self.api.baremetal.nodes.assert_called_once_with(associated=True,
                                                          details=True)
